@@ -19,7 +19,10 @@ ChernoCommandType = Union[Command[ChernoActor], FakeCommand]
 
 from .acquire import *
 from .guide import *
+from .mock import *
 from .offset import *
+from .scale import *
 from .set import *
 from .show import *
+from .status import *
 from .stop import *
